@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -26,7 +26,7 @@ class SendLaterConfigureDialogTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit SendLaterConfigureDialogTest(QObject *parent = Q_NULLPTR);
+    explicit SendLaterConfigureDialogTest(QObject *parent = nullptr);
     ~SendLaterConfigureDialogTest();
 private Q_SLOTS:
     void shouldHaveDefaultValue();
