@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -127,7 +127,7 @@ void SecurityPage::GeneralTab::save()
                                                KStandardGuiItem::cont(), KStandardGuiItem::cancel(), QStringLiteral("htmlMailOverride")) == KMessageBox::Continue) {
             saveCheckBox(mSGTab.mHtmlMailCheck, MessageViewer::MessageViewerSettings::self()->htmlMailItem());
             if (kmkernel) {
-                foreach (const Akonadi::Collection &collection, kmkernel->allFolders()) {
+                for (const Akonadi::Collection &collection : kmkernel->allFolders()) {
                     KConfigGroup config(KMKernel::self()->config(), MailCommon::FolderCollection::configGroupName(collection));
                     //Old config
                     config.deleteEntry("htmlMailOverride");
@@ -459,7 +459,7 @@ static void initializeDirmngrCheckbox(QCheckBox *cb, QGpgME::CryptoConfigEntry *
 }
 
 struct SMIMECryptoConfigEntries {
-    SMIMECryptoConfigEntries(QGpgME::CryptoConfig *config)
+    explicit SMIMECryptoConfigEntries(QGpgME::CryptoConfig *config)
         : mConfig(config)
     {
 
@@ -678,11 +678,11 @@ QGpgME::CryptoConfigEntry *SMIMECryptoConfigEntries::configEntry(const QString &
     QGpgME::CryptoConfigEntry *entry = mConfig->entry(componentName, groupName, entryName);
     if (!entry) {
         qCWarning(KMAIL_LOG) << QStringLiteral("Backend error: gpgconf doesn't seem to know the entry for %1/%2/%3").arg(componentName, groupName, entryName);
-        return Q_NULLPTR;
+        return nullptr;
     }
     if (entry->argType() != argType || entry->isList() != isList) {
         qCWarning(KMAIL_LOG) << QStringLiteral("Backend error: gpgconf has wrong type for %1/%2/%3: %4 %5").arg(componentName, groupName, entryName).arg(entry->argType()).arg(entry->isList());
-        return Q_NULLPTR;
+        return nullptr;
     }
     return entry;
 }
