@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -30,7 +30,7 @@
 
 RemoveCollectionJob::RemoveCollectionJob(QObject *parent)
     : QObject(parent),
-      mMainWidget(Q_NULLPTR)
+      mMainWidget(nullptr)
 {
 
 }
