@@ -1,7 +1,7 @@
 /*
     This file is part of KMail, the KDE mail client.
     Copyright (c) 2002 Don Sanders <sanders@kde.org>
-    Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+    Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
     KMail is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License, version 2, as
@@ -49,6 +49,9 @@
 #include "util.h"
 #include "settings/kmailsettings.h"
 #include "kmail_debug.h"
+#include "helper_p.h"
+#include "job/createreplymessagejob.h"
+#include "job/createforwardmessagejob.h"
 
 #include "editor/composer.h"
 #include "kmmainwidget.h"
@@ -85,7 +88,6 @@
 #include <MessageComposer/MessageSender>
 #include <MessageComposer/MessageHelper>
 #include <MessageComposer/MessageComposerSettings>
-#include <MessageComposer/MessageFactory>
 #include <MessageComposer/Util>
 
 #include <MessageList/Pane>
@@ -99,8 +101,8 @@
 #include <MimeTreeParser/NodeHelper>
 #include <MimeTreeParser/ObjectTreeParser>
 
-#include <MailTransport/TransportAttribute>
-#include <MailTransport/SentBehaviourAttribute>
+#include <MailTransportAkonadi/TransportAttribute>
+#include <MailTransportAkonadi/SentBehaviourAttribute>
 #include <MailTransport/TransportManager>
 
 #include <Libkdepim/ProgressManager>
@@ -139,7 +141,7 @@
 
 using KMail::SecondaryWindow;
 using MailTransport::TransportManager;
-using MessageComposer::MessageFactory;
+using MessageComposer::MessageFactoryNG;
 
 using KPIM::ProgressManager;
 using KPIM::ProgressItem;
@@ -147,15 +149,6 @@ using namespace KMime;
 
 using namespace MailCommon;
 
-/// Small helper function to get the composer context from a reply
-static KMail::Composer::TemplateContext replyContext(MessageFactory::MessageReply reply)
-{
-    if (reply.replyAll) {
-        return KMail::Composer::ReplyToAll;
-    } else {
-        return KMail::Composer::Reply;
-    }
-}
 
 /// Helper to sanely show an error message for a job
 static void showJobError(KJob *job)
@@ -269,7 +262,7 @@ void KMCommand::start()
     }
 
     // we can only retrieve items with a valid id
-    foreach (const Akonadi::Item &item, mMsgList) {
+    for (const Akonadi::Item &item : qAsConst(mMsgList)) {
         if (!item.isValid()) {
             Q_EMIT messagesTransfered(Failed);
             return;
@@ -447,22 +440,16 @@ KMCommand::Result KMMailtoReplyCommand::execute()
     if (!msg) {
         return Failed;
     }
-    MessageFactory factory(msg, item.id(), MailCommon::Util::updatedCollection(item.parentCollection()));
-    factory.setIdentityManager(KMKernel::self()->identityManager());
-    factory.setFolderIdentity(MailCommon::Util::folderIdentity(item));
-    factory.setMailingListAddresses(KMail::Util::mailingListsFromMessage(item));
-    factory.putRepliesInSameFolder(KMail::Util::putRepliesInSameFolder(item));
-    factory.setReplyStrategy(MessageComposer::ReplyNone);
-    factory.setSelection(mSelection);
-    KMime::Message::Ptr rmsg = factory.createReply().msg;
-    rmsg->to()->fromUnicodeString(KEmailAddress::decodeMailtoUrl(mUrl), "utf-8");
-    bool lastEncrypt = false;
-    bool lastSign = false;
-    KMail::Util::lastEncryptAndSignState(lastEncrypt, lastSign, msg);
+    CreateReplyMessageJobSettings settings;
+    settings.mItem = item;
+    settings.mMsg = msg;
+    settings.mSelection = mSelection;
+    settings.mUrl = mUrl;
+    settings.m_replyStrategy = MessageComposer::ReplyNone;
 
-    KMail::Composer *win = KMail::makeComposer(rmsg, lastSign, lastEncrypt, KMail::Composer::Reply, 0, mSelection);
-    win->setFocusToEditor();
-    win->show();
+    CreateReplyMessageJob *job = new CreateReplyMessageJob;
+    job->setSettings(settings);
+    job->start();
 
     return OK;
 }
@@ -483,18 +470,14 @@ KMCommand::Result KMMailtoForwardCommand::execute()
     if (!msg) {
         return Failed;
     }
-    MessageFactory factory(msg, item.id(), MailCommon::Util::updatedCollection(item.parentCollection()));
-    factory.setIdentityManager(KMKernel::self()->identityManager());
-    factory.setFolderIdentity(MailCommon::Util::folderIdentity(item));
-    KMime::Message::Ptr fmsg = factory.createForward();
-    fmsg->to()->fromUnicodeString(KEmailAddress::decodeMailtoUrl(mUrl).toLower(), "utf-8");
-    bool lastEncrypt = false;
-    bool lastSign = false;
-    KMail::Util::lastEncryptAndSignState(lastEncrypt, lastSign, msg);
-
-    KMail::Composer *win = KMail::makeComposer(fmsg, lastSign, lastEncrypt, KMail::Composer::Forward);
-    win->show();
+    CreateForwardMessageJobSettings settings;
+    settings.mItem = item;
+    settings.mMsg = msg;
+    settings.mUrl = mUrl;
 
+    CreateForwardMessageJob *job = new CreateForwardMessageJob;
+    job->setSettings(settings);
+    job->start();
     return OK;
 }
 
@@ -550,7 +533,7 @@ KMCommand::Result KMUrlSaveCommand::execute()
     }
 
     if (fileExists) {
-        if (KMessageBox::warningContinueCancel(Q_NULLPTR,
+        if (KMessageBox::warningContinueCancel(nullptr,
                                                xi18nc("@info", "File <filename>%1</filename> exists.<nl/>Do you want to replace it?",
                                                        saveUrl.toDisplayString()), i18n("Save to File"), KGuiItem(i18n("&Replace")))
                 != KMessageBox::Continue) {
@@ -734,7 +717,7 @@ KMOpenMsgCommand::KMOpenMsgCommand(QWidget *parent, const QUrl &url,
                                    const QString &encoding, KMMainWidget *main)
     : KMCommand(parent),
       mUrl(url),
-      mJob(Q_NULLPTR),
+      mJob(nullptr),
       mEncoding(encoding),
       mMainWidget(main)
 {
@@ -823,7 +806,7 @@ void KMOpenMsgCommand::slotResult(KJob *job)
         msg->setContent(KMime::CRLFtoLF(mMsgString.mid(startOfMessage, endOfMessage - startOfMessage).toUtf8()));
         msg->parse();
         if (!msg->hasContent()) {
-            delete msg; msg = Q_NULLPTR;
+            delete msg; msg = nullptr;
             doesNotContainMessage();
             return;
         }
@@ -869,28 +852,17 @@ KMCommand::Result KMReplyCommand::execute()
         return Failed;
     }
 
-    MessageFactory factory(msg, item.id(), MailCommon::Util::updatedCollection(item.parentCollection()));
-    factory.setIdentityManager(KMKernel::self()->identityManager());
-    factory.setFolderIdentity(MailCommon::Util::folderIdentity(item));
-    factory.setMailingListAddresses(KMail::Util::mailingListsFromMessage(item));
-    factory.putRepliesInSameFolder(KMail::Util::putRepliesInSameFolder(item));
-    factory.setReplyStrategy(m_replyStrategy);
-    factory.setSelection(mSelection);
-    if (!mTemplate.isEmpty()) {
-        factory.setTemplate(mTemplate);
-    }
-    if (mNoQuote) {
-        factory.setQuote(false);
-    }
-    bool lastEncrypt = false;
-    bool lastSign = false;
-    KMail::Util::lastEncryptAndSignState(lastEncrypt, lastSign, msg);
+    CreateReplyMessageJobSettings settings;
+    settings.mItem = item;
+    settings.mMsg = msg;
+    settings.mSelection = mSelection;
+    settings.m_replyStrategy = m_replyStrategy;
+    settings.mTemplate = mTemplate;
+    settings.mNoQuote = mNoQuote;
 
-    MessageFactory::MessageReply reply = factory.createReply();
-    KMail::Composer *win = KMail::makeComposer(KMime::Message::Ptr(reply.msg), lastSign, lastEncrypt, replyContext(reply), 0,
-                           mSelection, mTemplate);
-    win->setFocusToEditor();
-    win->show();
+    CreateReplyMessageJob *job = new CreateReplyMessageJob;
+    job->setSettings(settings);
+    job->start();
 
     return OK;
 }
@@ -926,31 +898,17 @@ KMCommand::Result KMForwardCommand::createComposer(const Akonadi::Item &item)
 #ifndef QT_NO_CURSOR
     KPIM::KCursorSaver busy(KPIM::KBusyPtr::busy());
 #endif
-    MessageFactory factory(msg, item.id(), MailCommon::Util::updatedCollection(item.parentCollection()));
-    factory.setIdentityManager(KMKernel::self()->identityManager());
-    factory.setFolderIdentity(MailCommon::Util::folderIdentity(item));
-    factory.setSelection(mSelection);
-    if (!mTemplate.isEmpty()) {
-        factory.setTemplate(mTemplate);
-    }
-    KMime::Message::Ptr fwdMsg = factory.createForward();
 
-    uint id = 0;
-    if (auto hrd = msg->headerByType("X-KMail-Identity")) {
-        id = hrd->asUnicodeString().trimmed().toUInt();
-    }
-    qCDebug(KMAIL_LOG) << "mail" << msg->encodedContent();
-    bool lastEncrypt = false;
-    bool lastSign = false;
-    KMail::Util::lastEncryptAndSignState(lastEncrypt, lastSign, msg);
+    CreateForwardMessageJobSettings settings;
+    settings.mItem = item;
+    settings.mMsg = msg;
+    settings.mIdentity = mIdentity;
+    settings.mTemplate = mTemplate;
+    settings.mSelection = mSelection;
 
-    if (id == 0) {
-        id = mIdentity;
-    }
-    {
-        KMail::Composer *win = KMail::makeComposer(fwdMsg, lastSign, lastEncrypt, KMail::Composer::Forward, id, QString(), mTemplate);
-        win->show();
-    }
+    CreateForwardMessageJob *job = new CreateForwardMessageJob;
+    job->setSettings(settings);
+    job->start();
     return OK;
 }
 
@@ -971,7 +929,7 @@ KMCommand::Result KMForwardCommand::execute()
 
         if (answer == KMessageBox::Yes) {
             Akonadi::Item firstItem(msgList.first());
-            MessageFactory factory(KMime::Message::Ptr(new KMime::Message), firstItem.id(), MailCommon::Util::updatedCollection(firstItem.parentCollection()));
+            MessageFactoryNG factory(KMime::Message::Ptr(new KMime::Message), firstItem.id(), MailCommon::Util::updatedCollection(firstItem.parentCollection()));
             factory.setIdentityManager(KMKernel::self()->identityManager());
             factory.setFolderIdentity(MailCommon::Util::folderIdentity(firstItem));
 
@@ -1026,7 +984,7 @@ KMCommand::Result KMForwardAttachedCommand::execute()
 {
     Akonadi::Item::List msgList = retrievedMsgs();
     Akonadi::Item firstItem(msgList.first());
-    MessageFactory factory(KMime::Message::Ptr(new KMime::Message), firstItem.id(), MailCommon::Util::updatedCollection(firstItem.parentCollection()));
+    MessageFactoryNG factory(KMime::Message::Ptr(new KMime::Message), firstItem.id(), MailCommon::Util::updatedCollection(firstItem.parentCollection()));
     factory.setIdentityManager(KMKernel::self()->identityManager());
     factory.setFolderIdentity(MailCommon::Util::folderIdentity(firstItem));
 
@@ -1034,7 +992,7 @@ KMCommand::Result KMForwardAttachedCommand::execute()
     if (!mWin) {
         mWin = KMail::makeComposer(fwdMsg.first, false, false, KMail::Composer::Forward, mIdentity);
     }
-    foreach (KMime::Content *attach, fwdMsg.second) {
+    for (KMime::Content *attach : qAsConst(fwdMsg.second)) {
         mWin->addAttach(attach);
     }
     mWin->show();
@@ -1088,13 +1046,13 @@ KMCommand::Result KMRedirectCommand::execute()
     const QString to = dlg->to();
     const QString cc = dlg->cc();
     const QString bcc = dlg->bcc();
-    foreach (const Akonadi::Item &item, retrievedMsgs()) {
+    const Akonadi::Item::List lstItems = retrievedMsgs();
+    for (const Akonadi::Item &item : lstItems) {
         const KMime::Message::Ptr msg = MessageCore::Util::message(item);
         if (!msg) {
             return Failed;
         }
-
-        MessageFactory factory(msg, item.id(), MailCommon::Util::updatedCollection(item.parentCollection()));
+        MessageFactoryNG factory(msg, item.id(), MailCommon::Util::updatedCollection(item.parentCollection()));
         factory.setIdentityManager(KMKernel::self()->identityManager());
         factory.setFolderIdentity(MailCommon::Util::folderIdentity(item));
 
@@ -1141,7 +1099,7 @@ KMPrintCommand::KMPrintCommand(QWidget *parent, const Akonadi::Item &msg,
                                bool useFixedFont, const QString &encoding)
     : KMCommand(parent, msg),
       mHeaderStylePlugin(plugin),
-      mAttachmentStrategy(Q_NULLPTR),
+      mAttachmentStrategy(nullptr),
       mEncoding(encoding),
       mFormat(format),
       mHtmlLoadExtOverride(htmlLoadExtOverride),
@@ -1173,7 +1131,7 @@ void KMPrintCommand::setPrintPreview(bool preview)
 
 KMCommand::Result KMPrintCommand::execute()
 {
-    KMReaderWin *printerWin = new KMReaderWin(Q_NULLPTR, kmkernel->mainWin(), Q_NULLPTR);
+    KMReaderWin *printerWin = new KMReaderWin(nullptr, kmkernel->mainWin(), nullptr);
     printerWin->setPrinting(true);
     printerWin->readConfig();
     printerWin->setPrintElementBackground(MessageViewer::MessageViewerSettings::self()->printBackgroundColorImages());
@@ -1199,7 +1157,7 @@ KMCommand::Result KMPrintCommand::execute()
 
 KMSetStatusCommand::KMSetStatusCommand(const MessageStatus &status,
                                        const Akonadi::Item::List &items, bool invert)
-    : KMCommand(Q_NULLPTR, items), mStatus(status), mInvertMark(invert)
+    : KMCommand(nullptr, items), mStatus(status), mInvertMark(invert)
 {
     setDeletesItself(true);
 }
@@ -1221,7 +1179,8 @@ KMCommand::Result KMSetStatusCommand::execute()
     }
 
     Akonadi::Item::List itemsToModify;
-    foreach (const Akonadi::Item &it, retrievedMsgs()) {
+    const Akonadi::Item::List lstItems = retrievedMsgs();
+    for (const Akonadi::Item &it : lstItems) {
         if (mInvertMark) {
             //qCDebug(KMAIL_LOG)<<" item ::"<<tmpItem;
             if (it.isValid()) {
@@ -1257,7 +1216,7 @@ KMCommand::Result KMSetStatusCommand::execute()
     }
 
     if (itemsToModify.isEmpty()) {
-        slotModifyItemDone(Q_NULLPTR);   // pretend we did something
+        slotModifyItemDone(nullptr);   // pretend we did something
     } else {
         Akonadi::ItemModifyJob *modifyJob = new Akonadi::ItemModifyJob(itemsToModify, this);
         modifyJob->disableRevisionCheck();
@@ -1286,7 +1245,7 @@ KMSetTagCommand::KMSetTagCommand(const Akonadi::Tag::List &tags, const Akonadi::
 
 KMCommand::Result KMSetTagCommand::execute()
 {
-    Q_FOREACH (const Akonadi::Tag &tag, mTags) {
+    for (const Akonadi::Tag &tag : qAsConst(mTags)) {
         if (!tag.isValid()) {
             Akonadi::TagCreateJob *createJob = new Akonadi::TagCreateJob(tag, this);
             connect(createJob, &Akonadi::TagCreateJob::result, this, &KMSetTagCommand::slotModifyItemDone);
@@ -1308,18 +1267,19 @@ void KMSetTagCommand::setTags()
 {
     Akonadi::Item::List itemsToModify;
     itemsToModify.reserve(mItem.count());
-    Q_FOREACH (const Akonadi::Item &i, mItem) {
+    for (const Akonadi::Item &i : qAsConst(mItem)) {
         Akonadi::Item item(i);
         if (mMode == CleanExistingAndAddNew) {
             //WorkAround. ClearTags doesn't work.
-            Q_FOREACH (const Akonadi::Tag &tag, item.tags()) {
+            const Akonadi::Tag::List lstTags = item.tags();
+            for (const Akonadi::Tag &tag : lstTags) {
                 item.clearTag(tag);
             }
             //item.clearTags();
         }
 
         if (mMode == KMSetTagCommand::Toggle) {
-            Q_FOREACH (const Akonadi::Tag &tag, mCreatedTags) {
+            for (const Akonadi::Tag &tag : qAsConst(mCreatedTags)) {
                 if (item.hasTag(tag)) {
                     item.clearTag(tag);
                 } else {
@@ -1342,7 +1302,7 @@ void KMSetTagCommand::setTags()
         KConfigGroup tag(KMKernel::self()->config(), "MessageListView");
         const QString oldTagList = tag.readEntry("TagSelected");
         QStringList lst = oldTagList.split(QLatin1Char(','));
-        Q_FOREACH (const Akonadi::Tag &tag, mCreatedTags) {
+        for (const Akonadi::Tag &tag : qAsConst(mCreatedTags)) {
             const QString url = tag.url().url();
             if (!lst.contains(url)) {
                 lst.append(url);
@@ -1381,7 +1341,7 @@ KMCommand::Result KMFilterActionCommand::execute()
             i18n("Filtering messages"), QString(), true, KPIM::ProgressItem::Unknown);
     progressItem->setTotalItems(msgCountToFilter);
 
-    foreach (const qlonglong &id, mMsgListId) {
+    for (const qlonglong &id : qAsConst(mMsgListId)) {
         int diff = msgCountToFilter - ++msgCount;
         if (diff < 10 || !(msgCount % 10) || msgCount <= 10) {
             progressItem->updateProgress();
@@ -1396,7 +1356,7 @@ KMCommand::Result KMFilterActionCommand::execute()
     }
 
     progressItem->setComplete();
-    progressItem = Q_NULLPTR;
+    progressItem = nullptr;
     return OK;
 }
 
@@ -1440,12 +1400,12 @@ KMCommand::Result KMMailingListFilterCommand::execute()
 
 KMCopyCommand::KMCopyCommand(const Akonadi::Collection &destFolder,
                              const Akonadi::Item::List &msgList)
-    : KMCommand(Q_NULLPTR, msgList), mDestFolder(destFolder)
+    : KMCommand(nullptr, msgList), mDestFolder(destFolder)
 {
 }
 
 KMCopyCommand::KMCopyCommand(const Akonadi::Collection &destFolder, const Akonadi::Item &msg)
-    : KMCommand(Q_NULLPTR, msg), mDestFolder(destFolder)
+    : KMCommand(nullptr, msg), mDestFolder(destFolder)
 {
 }
 
@@ -1474,7 +1434,7 @@ void KMCopyCommand::slotCopyResult(KJob *job)
 KMMoveCommand::KMMoveCommand(const Akonadi::Collection &destFolder,
                              const Akonadi::Item::List &msgList,
                              MessageList::Core::MessageItemSetReference ref)
-    : KMCommand(Q_NULLPTR, msgList), mDestFolder(destFolder), mProgressItem(Q_NULLPTR), mRef(ref)
+    : KMCommand(nullptr, msgList), mDestFolder(destFolder), mProgressItem(nullptr), mRef(ref)
 {
     fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
 }
@@ -1482,7 +1442,7 @@ KMMoveCommand::KMMoveCommand(const Akonadi::Collection &destFolder,
 KMMoveCommand::KMMoveCommand(const Akonadi::Collection &destFolder,
                              const Akonadi::Item &msg,
                              MessageList::Core::MessageItemSetReference ref)
-    : KMCommand(Q_NULLPTR, msg), mDestFolder(destFolder), mProgressItem(Q_NULLPTR), mRef(ref)
+    : KMCommand(nullptr, msg), mDestFolder(destFolder), mProgressItem(nullptr), mRef(ref)
 {
     fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
 }
@@ -1518,7 +1478,7 @@ KMCommand::Result KMMoveCommand::execute()
             });
             Akonadi::Collection parent;
             int undoId = -1;
-            foreach (const Akonadi::Item &item, retrievedList) {
+            for (const Akonadi::Item &item : qAsConst(retrievedList)) {
                 if (item.storageCollectionId() <= 0) {
                     continue;
                 }
@@ -1551,7 +1511,7 @@ void KMMoveCommand::completeMove(Result result)
 {
     if (mProgressItem) {
         mProgressItem->setComplete();
-        mProgressItem = Q_NULLPTR;
+        mProgressItem = nullptr;
     }
     setResult(result);
     Q_EMIT moveDone(this);
@@ -1597,7 +1557,7 @@ KMSaveAttachmentsCommand::KMSaveAttachmentsCommand(QWidget *parent, const Akonad
 
 KMSaveAttachmentsCommand::KMSaveAttachmentsCommand(QWidget *parent, const Akonadi::Item::List &msgs)
     : KMCommand(parent, msgs),
-      mViewer(Q_NULLPTR)
+      mViewer(nullptr)
 {
     fetchScope().fetchFullPayload(true);
 }
@@ -1605,7 +1565,8 @@ KMSaveAttachmentsCommand::KMSaveAttachmentsCommand(QWidget *parent, const Akonad
 KMCommand::Result KMSaveAttachmentsCommand::execute()
 {
     KMime::Content::List contentsToSave;
-    foreach (const Akonadi::Item &item, retrievedMsgs()) {
+    const Akonadi::Item::List lstItems = retrievedMsgs();
+    for (const Akonadi::Item &item : lstItems) {
         if (item.hasPayload<KMime::Message::Ptr>()) {
             contentsToSave += item.payload<KMime::Message::Ptr>()->attachments();
         } else {
@@ -1637,8 +1598,7 @@ KMCommand::Result KMResendMessageCommand::execute()
     if (!msg) {
         return Failed;
     }
-
-    MessageFactory factory(msg, item.id(), MailCommon::Util::updatedCollection(item.parentCollection()));
+    MessageFactoryNG factory(msg, item.id(), MailCommon::Util::updatedCollection(item.parentCollection()));
     factory.setIdentityManager(KMKernel::self()->identityManager());
     factory.setFolderIdentity(MailCommon::Util::folderIdentity(item));
     KMime::Message::Ptr newMsg = factory.createResend();
