@@ -32,11 +32,13 @@ void KMMigrateApplication::migrate()
 {
     // Migrate to xdg.
     Kdelibs4ConfigMigrator migrate(QStringLiteral("kmail"));
+
     migrate.setConfigFiles(QStringList() << QStringLiteral("kmail2rc") << QStringLiteral("kmail2.notifyrc") << QStringLiteral("kmailsnippetrc")
                            << QStringLiteral("customtemplatesrc") << QStringLiteral("templatesconfigurationrc") << QStringLiteral("kpimcompletionorder")
-                           << QStringLiteral("messageviewer.notifyrc") << QStringLiteral("sievetemplaterc") << QStringLiteral("foldermailarchiverc"));
+                           << QStringLiteral("messageviewer.notifyrc") << QStringLiteral("sievetemplaterc") << QStringLiteral("foldermailarchiverc")
+                           << QStringLiteral("kpimbalooblacklist"));
     migrate.setUiFiles(QStringList() << QStringLiteral("kmail_part.rc") << QStringLiteral("kmcomposerui.rc") <<  QStringLiteral("kmmainwin.rc")
-                       <<  QStringLiteral("kmreadermainwin.rc"));
+                       << QStringLiteral("kmreadermainwin.rc"));
     migrate.migrate();
 
     // Migrate folders and files.
