@@ -6,7 +6,7 @@
     copyright            : (C) 2001 by Ryan Breen
     email                : ryan@porivo.com
 
-    Copyright (c) 2010-2016 Montel Laurent <montel@kde.org>
+    Copyright (c) 2010-2017 Montel Laurent <montel@kde.org>
  ***************************************************************************/
 
 /***************************************************************************
@@ -62,8 +62,8 @@ KMSystemTray::KMSystemTray(QObject *parent)
       mDesktopOfMainWin(0),
       mCount(0),
       mIconNotificationsEnabled(true),
-      mNewMessagesPopup(Q_NULLPTR),
-      mSendQueued(Q_NULLPTR)
+      mNewMessagesPopup(nullptr),
+      mSendQueued(nullptr)
 {
     qCDebug(KMAIL_LOG) << "Initting systray";
     setToolTipTitle(i18n("KMail"));
@@ -217,10 +217,10 @@ void KMSystemTray::slotContextMenuAboutToShow()
         return;
     }
 
-    if (mNewMessagesPopup != Q_NULLPTR) {
+    if (mNewMessagesPopup != nullptr) {
         contextMenu()->removeAction(mNewMessagesPopup->menuAction());
         delete mNewMessagesPopup;
-        mNewMessagesPopup = Q_NULLPTR;
+        mNewMessagesPopup = nullptr;
     }
     mNewMessagesPopup = new QMenu();
     fillFoldersMenu(mNewMessagesPopup, kmkernel->treeviewModelSelection());
@@ -370,10 +370,7 @@ void KMSystemTray::slotCollectionStatisticsChanged(Akonadi::Collection::Id id, c
 
 bool KMSystemTray::excludeFolder(const Akonadi::Collection &collection) const
 {
-    if (!collection.isValid()) {
-        return true;
-    }
-    if (!collection.contentMimeTypes().contains(KMime::Message::mimeType())) {
+    if (!collection.isValid() || !collection.contentMimeTypes().contains(KMime::Message::mimeType())) {
         return true;
     }
     if (CommonKernel->outboxCollectionFolder() == collection ||
